@@ -1,11 +1,10 @@
 #!perl 
 
-# (c) 2002 by Murat Uenalan. All rights reserved. Note: This program is
+# (c) 2004 by Murat Uenalan. All rights reserved. Note: This program is
 # free software; you can redistribute it and/or modify it under the same
 # terms as perl itself
 
-
-use lib;
+use blib;
 
 use Benchmark qw(:all);
 
